==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyV1beta1SupplementalGroupsStrategyOptionsFluent<A extends PolicyV1beta1SupplementalGroupsStrategyOptionsFluent<A>> extends Fluent<A>{


    public A addToRanges(int index,PolicyV1beta1IDRange item);
    public A setToRanges(int index,PolicyV1beta1IDRange item);
    public A addToRanges(PolicyV1beta1IDRange... items);
    public A addAllToRanges(Collection<PolicyV1beta1IDRange> items);
    public A removeFromRanges(PolicyV1beta1IDRange... items);
    public A removeAllFromRanges(Collection<PolicyV1beta1IDRange> items);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<PolicyV1beta1IDRange> getRanges();
    public List<PolicyV1beta1IDRange> buildRanges();
    public PolicyV1beta1IDRange buildRange(int index);
    public PolicyV1beta1IDRange buildFirstRange();
    public PolicyV1beta1IDRange buildLastRange();
    public PolicyV1beta1IDRange buildMatchingRange(io.kubernetes.client.fluent.Predicate<PolicyV1beta1IDRangeBuilder> predicate);
    public A withRanges(List<PolicyV1beta1IDRange> ranges);
    public A withRanges(PolicyV1beta1IDRange... ranges);
    public Boolean hasRanges();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> addNewRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> addNewRangeLike(PolicyV1beta1IDRange item);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,PolicyV1beta1IDRange item);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editLastRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editMatchingRange(io.kubernetes.client.fluent.Predicate<PolicyV1beta1IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();

    public interface RangesNested<N> extends io.kubernetes.client.fluent.Nested<N>,PolicyV1beta1IDRangeFluent<PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<N>>{

        
    public N and();    public N endRange();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyV1beta1SupplementalGroupsStrategyOptionsFluent<A extends PolicyV1beta1SupplementalGroupsStrategyOptionsFluent<A>> extends Fluent<A>{


    public A addToRanges(int index,PolicyV1beta1IDRange item);
    public A setToRanges(int index,PolicyV1beta1IDRange item);
    public A addToRanges(PolicyV1beta1IDRange... items);
    public A addAllToRanges(Collection<PolicyV1beta1IDRange> items);
    public A removeFromRanges(PolicyV1beta1IDRange... items);
    public A removeAllFromRanges(Collection<PolicyV1beta1IDRange> items);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<PolicyV1beta1IDRange> getRanges();
    public List<PolicyV1beta1IDRange> buildRanges();
    public PolicyV1beta1IDRange buildRange(int index);
    public PolicyV1beta1IDRange buildFirstRange();
    public PolicyV1beta1IDRange buildLastRange();
    public PolicyV1beta1IDRange buildMatchingRange(io.kubernetes.client.fluent.Predicate<PolicyV1beta1IDRangeBuilder> predicate);
    public Boolean hasMatchingRange(io.kubernetes.client.fluent.Predicate<PolicyV1beta1IDRangeBuilder> predicate);
    public A withRanges(List<PolicyV1beta1IDRange> ranges);
    public A withRanges(PolicyV1beta1IDRange... ranges);
    public Boolean hasRanges();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> addNewRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> addNewRangeLike(PolicyV1beta1IDRange item);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,PolicyV1beta1IDRange item);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editLastRange();
    public PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<A> editMatchingRange(io.kubernetes.client.fluent.Predicate<PolicyV1beta1IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    public A withNewRule(String arg1);
    public A withNewRule(StringBuilder arg1);
    public A withNewRule(StringBuffer arg1);

    public interface RangesNested<N> extends io.kubernetes.client.fluent.Nested<N>,PolicyV1beta1IDRangeFluent<PolicyV1beta1SupplementalGroupsStrategyOptionsFluent.RangesNested<N>>{

        
    public N and();    public N endRange();
}


}
